# sshclient &middot; [![MIT license](https://img.shields.io/badge/license-MIT-blue.svg)](https://github.com/cdr/sshclient/blob/master/LICENSE) [!["Latest Release"](https://img.shields.io/github/release/cdr/sshclient.svg)](https://github.com/cdr/sshclient/releases/latest)

`sshclient` is a JavaScript library to process client SSH connections. It communicates with an OpenSSH server.

❤️ to [gopherjs](https://github.com/gopherjs/gopherjs). `sshclient` uses the `golang.org/x/crypto/ssh` implementation. Currently the following functionality has been exposed from their API:

- Port forwarding
- PTYs
- Exec

## Usage

```ts
import * as sshclient from "@coder/sshclient"

// The server hosting this socket is serving sshd on
// port 22 from the host.
const socket = new WebSocket("ws://localhost:8080/ssh")
socket.binaryType = "arraybuffer"
socket.addEventListener("open", () => {
    const conn = sshclient.createConnection((data) => {
        socket.send(data)
    })

    socket.addEventListener("message", (event) => {
        conn.writeToClient(new Uint8Array(event.data))
    })

    sshclient.createClient(conn, {
        username: "kyle",
        password: "example",
    }).then((client) => {
        // 🎊
    })
})
```

## Development

You must have [gopherjs](https://github.com/gopherjs/gopherjs) and Go 1.12.

```bash
yarn
yarn dev
```

Go source code will be transformed and hot-reloaded by Webpack via `gopherjs-loader.js`.

## License

[MIT](LICENSE.md)