/// <reference types="node" />
import { Writable, Readable } from "stream";
export declare enum Signal {
    SIGABRT = "ABRT",
    SIGALRM = "ALRM",
    SIGFPE = "FPE",
    SIGHUP = "HUP",
    SIGILL = "ILL",
    SIGINT = "INT",
    SIGKILL = "KILL",
    SIGPIPE = "PIPE",
    SIGQUIT = "QUIT",
    SIGSEGV = "SEGV",
    SIGTERM = "TERM",
    SIGUSR1 = "USR1",
    SIGUSR2 = "USR2"
}
export declare enum TerminalMode {
    tty_OP_END = 0,
    VINTR = 1,
    VQUIT = 2,
    VERASE = 3,
    VKILL = 4,
    VEOF = 5,
    VEOL = 6,
    VEOL2 = 7,
    VSTART = 8,
    VSTOP = 9,
    VSUSP = 10,
    VDSUSP = 11,
    VREPRINT = 12,
    VWERASE = 13,
    VLNEXT = 14,
    VFLUSH = 15,
    VSWTCH = 16,
    VSTATUS = 17,
    VDISCARD = 18,
    IGNPAR = 30,
    PARMRK = 31,
    INPCK = 32,
    ISTRIP = 33,
    INLCR = 34,
    IGNCR = 35,
    ICRNL = 36,
    IUCLC = 37,
    IXON = 38,
    IXANY = 39,
    IXOFF = 40,
    IMAXBEL = 41,
    ISIG = 50,
    ICANON = 51,
    XCASE = 52,
    ECHO = 53,
    ECHOE = 54,
    ECHOK = 55,
    ECHONL = 56,
    NOFLSH = 57,
    TOSTOP = 58,
    IEXTEN = 59,
    ECHOCTL = 60,
    ECHOKE = 61,
    PENDIN = 62,
    OPOST = 70,
    OLCUC = 71,
    ONLCR = 72,
    OCRNL = 73,
    ONOCR = 74,
    ONLRET = 75,
    CS7 = 90,
    CS8 = 91,
    PARENB = 92,
    PARODD = 93,
    TTY_OP_ISPEED = 128,
    TTY_OP_OSPEED = 129
}
export declare type TerminalModes = {
    readonly [key in TerminalMode]: number;
};
export interface Connection {
    writeToClient(data: Uint8Array): void;
    on(event: "close", cb: () => void): void;
}
export interface InternalConnection extends Connection {
    native: any;
}
export interface SSHClientOptions {
    readonly username: string;
    readonly password: string;
}
export interface Forwarder {
    on(event: "data", cb: (data: Uint8Array) => void): void;
    on(event: "close", cb: () => void): void;
    close(): void;
    write(data: Uint8Array): void;
}
export interface FileInfo {
    readonly isDir: boolean;
    readonly mtime: number;
    readonly mode: number;
    readonly name: string;
    readonly size: number;
}
export declare class Client {
    private readonly client;
    private readonly writeToClient;
    private readonly eventEmitter;
    constructor(client: any, writeToClient: (data: Uint8Array) => void);
    addEventListener(event: "uhh", callback: () => void): void;
    write(data: Uint8Array): void;
    createSession(): Promise<Session>;
    createForwarder(protocol: "tcp" | "udp", host: string): Promise<Forwarder>;
}
export declare function createConnection(writeToServer: (data: Uint8Array) => void): Connection;
export declare function createClient(connection: Connection, options: SSHClientOptions): Promise<Client>;
export declare class Session {
    private readonly session;
    readonly stdin: Writable;
    readonly stdout: Readable;
    readonly stderr: Readable;
    constructor(session: any);
    close(): Promise<void>;
    requestSFTP(): Promise<{
        readDir(path: string): Promise<FileInfo>;
    }>;
    /**
     * Requests the association of a pty with the session on the remote host.
     */
    requestPty(term: string, height: number, width: number, terminalModes: TerminalModes): Promise<void>;
    requestSubsystem(subsystem: string): Promise<void>;
    /**
     * Runs the cmd on the remote host.
     */
    runCommand(command: string): Promise<void>;
    /**
     * Sets an environment variable that will be applied to any command
     * executed by `startShell` or `runCommand`
     */
    setEnvironmentVariable(name: string, value: string): Promise<void>;
    /**
     * Starts a login shell on the remote host.
     */
    startShell(): Promise<void>;
    /**
     * Sends the given signal to the remote process.
     */
    sendSignal(signal: Signal): Promise<void>;
    /**
     * Waits for the remote command to exit.
     */
    wait(): Promise<void>;
    /**
     * Informs the remote host about a terminal window dimension change to h rows and w columns.
     */
    setPtyDimensions(height: number, width: number): Promise<void>;
}
